==> ejc-qualitymanagement-api-3.0.0-20250908.085520-56-sources.jar: com/ejianc/business/scene/vo/FeedbackPlanDetailVO.java <==
package com.ejianc.business.scene.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 应急演练计划清单
 * 
 * @author generator
 * 
 */
public class FeedbackPlanDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long feedbackCategory; // 反馈类型
    private Long feedbackType; // 反馈方式
    private Long feedbackSource; // 反馈来源
    private String feedbackContent; // 反馈内容
    private String feedbackObject; // 反馈对象
    private String unit; // 组织部门
    private Long frequency; // 反馈频次
    private BigDecimal mny; // 费用预算（万元）
    private String memo; // 备注
    private Long pid; // 主表id
    private String projectName; // 项目名称
    private String unitName; // 组织部门名称

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }

    @ReferSerialTransfer(referCode="support-defdoc")
    public Long getFeedbackCategory() {
        return feedbackCategory;
    }
    @ReferDeserialTransfer
    public void setFeedbackCategory(Long feedbackCategory) {
        this.feedbackCategory = feedbackCategory;
    }
    @ReferSerialTransfer(referCode="support-defdoc")
    public Long getFeedbackType() {
        return feedbackType;
    }
    @ReferDeserialTransfer
    public void setFeedbackType(Long feedbackType) {
        this.feedbackType = feedbackType;
    }
    @ReferSerialTransfer(referCode="support-defdoc")
    public Long getFeedbackSource() {
        return feedbackSource;
    }
    @ReferDeserialTransfer
    public void setFeedbackSource(Long feedbackSource) {
        this.feedbackSource = feedbackSource;
    }
    public String getFeedbackContent() {
        return feedbackContent;
    }

    public void setFeedbackContent(String feedbackContent) {
        this.feedbackContent = feedbackContent;
    }
    public String getFeedbackObject() {
        return feedbackObject;
    }

    public void setFeedbackObject(String feedbackObject) {
        this.feedbackObject = feedbackObject;
    }
    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }
    @ReferSerialTransfer(referCode="support-defdoc")
    public Long getFrequency() {
        return frequency;
    }
    @ReferDeserialTransfer
    public void setFrequency(Long frequency) {
        this.frequency = frequency;
    }
    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }
    
}

==> ejc-qualitymanagement-api-3.0.0-20251117.094605-78-sources.jar: com/ejianc/business/scene/vo/FeedbackPlanDetailVO.java <==
package com.ejianc.business.scene.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 应急演练计划清单
 * 
 * @author generator
 * 
 */
public class FeedbackPlanDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long feedbackCategory; // 反馈类型
    private String feedbackCategoryName; // 反馈类型
    private Long feedbackType; // 反馈方式
    private String feedbackTypeName; // 反馈方式
    private Long feedbackSource; // 反馈来源
    private String feedbackSourceName; // 反馈来源
    private String feedbackContent; // 反馈内容
    private String feedbackObject; // 反馈对象
    private String unit; // 组织部门
    private Long frequency; // 反馈频次
    private BigDecimal mny; // 费用预算（万元）
    private String memo; // 备注
    private Long pid; // 主表id
    private String projectName; // 项目名称
    private String unitName; // 组织部门名称

    public String getFeedbackTypeName() {
        return feedbackTypeName;
    }

    public void setFeedbackTypeName(String feedbackTypeName) {
        this.feedbackTypeName = feedbackTypeName;
    }

    public String getFeedbackSourceName() {
        return feedbackSourceName;
    }

    public void setFeedbackSourceName(String feedbackSourceName) {
        this.feedbackSourceName = feedbackSourceName;
    }

    public String getFeedbackCategoryName() {
        return feedbackCategoryName;
    }

    public void setFeedbackCategoryName(String feedbackCategoryName) {
        this.feedbackCategoryName = feedbackCategoryName;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }

    @ReferSerialTransfer(referCode="support-defdoc")
    public Long getFeedbackCategory() {
        return feedbackCategory;
    }
    @ReferDeserialTransfer
    public void setFeedbackCategory(Long feedbackCategory) {
        this.feedbackCategory = feedbackCategory;
    }
    @ReferSerialTransfer(referCode="support-defdoc")
    public Long getFeedbackType() {
        return feedbackType;
    }
    @ReferDeserialTransfer
    public void setFeedbackType(Long feedbackType) {
        this.feedbackType = feedbackType;
    }
    @ReferSerialTransfer(referCode="support-defdoc")
    public Long getFeedbackSource() {
        return feedbackSource;
    }
    @ReferDeserialTransfer
    public void setFeedbackSource(Long feedbackSource) {
        this.feedbackSource = feedbackSource;
    }
    public String getFeedbackContent() {
        return feedbackContent;
    }

    public void setFeedbackContent(String feedbackContent) {
        this.feedbackContent = feedbackContent;
    }
    public String getFeedbackObject() {
        return feedbackObject;
    }

    public void setFeedbackObject(String feedbackObject) {
        this.feedbackObject = feedbackObject;
    }
    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }
    @ReferSerialTransfer(referCode="support-defdoc")
    public Long getFrequency() {
        return frequency;
    }
    @ReferDeserialTransfer
    public void setFrequency(Long frequency) {
        this.frequency = frequency;
    }
    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }
    
}
